@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-actions-bookmark.h,v 1.2 2003/11/10 21:50:10 makeinu Exp $
+ *  $Id: kz-actions-bookmark.h,v 1.3 2004/07/05 09:17:10 ikezoe Exp $
  */
 
 /*
@@ -32,16 +32,14 @@
 #endif /* HAVE_CONFIG_H */
 
 #include <glib.h>
-#include "egg-action-group.h"
+#include "gtk24backports.h"
 #include "kz-bookmark-editor.h"
 
 G_BEGIN_DECLS
 
-extern EggActionGroupEntry kz_actions_bookmark[];
-extern const gint          kz_actions_bookmark_len;
-
-EggActionGroup *kz_actions_bookmark_create_group (KzBookmarkEditor *editor,
+GtkActionGroup *kz_actions_bookmark_create_group (KzBookmarkEditor *editor,
 						  GtkAccelGroup *accel_group);
+
 void kz_actions_bookmark_popup_menu_modal (KzBookmarkEditor *editor,
 					   guint button, guint time);
 
