@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-editor.h,v 1.7 2003/11/11 03:25:31 makeinu Exp $
+ *  $Id: kz-bookmark-editor.h,v 1.10 2004/07/05 09:17:11 ikezoe Exp $
  */
 
 #ifndef __KZ_BOOKMARK_EDITOR_H__
@@ -25,7 +25,8 @@
 
 #include <gtk/gtk.h>
 #include "kz-bookmark.h"
-#include "egg-menu-merge.h"
+#include "gtk24backports.h"
+#include "kz-favicon.h"
 
 G_BEGIN_DECLS
 
@@ -56,8 +57,8 @@ struct _KzBookmarkEditor
 	KzBookmark *current_folder;
 
 	/* other objects */
-	EggActionGroup *action_group;
-	EggMenuMerge   *menu_merge;
+	GtkActionGroup *action_group;
+	GtkUIManager   *menu_merge;
 
 	KzBookmarkEditorPriv *priv;
 };
