@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-root-bookmark.c,v 1.6 2004/04/12 15:07:45 ikezoe Exp $
+ *  $Id: kz-root-bookmark.c,v 1.7 2004/07/08 08:01:24 ikezoe Exp $
  */
 
 #include "kz-root-bookmark.h"
@@ -65,6 +65,7 @@ kz_root_bookmark_init (KzRootBookmark *root)
 	root->sessions      = kz_bookmark_pure_folder_new();
 	root->windows       = kz_bookmark_pure_folder_new();
 	root->tab_groups    = kz_bookmark_pure_folder_new();
+	root->smarts        = NULL;
 
 	kz_bookmark_set_title(root->menu,                 "Bookmark Menu");
 	kz_bookmark_set_title(root->bookmark_bars,        "Bookmark Bars");
@@ -136,6 +137,11 @@ kz_root_bookmark_dispose (GObject *object)
 		g_object_unref(G_OBJECT(root->tab_groups));
 		root->tab_groups = NULL;
 	}
+	if (root->smarts)
+	{
+		g_object_unref(G_OBJECT(root->smarts));
+		root->smarts = NULL;
+	}
 
 	if (G_OBJECT_CLASS (parent_class)->dispose)
 		G_OBJECT_CLASS (parent_class)->dispose(object);
@@ -159,7 +165,7 @@ kz_root_bookmark_new (const gchar *menu_file,  const gchar *sys_menu_file,
 		kz_bookmark_append(KZ_BOOKMARK(root), root->scrap);
 	if (root->bookmark_bars)
 		kz_bookmark_append(KZ_BOOKMARK(root), root->bookmark_bars);
-	/*
+/*
 	kz_bookmark_append(KZ_BOOKMARK(root), KZ_BOOKMARK(root->history));
 	kz_bookmark_append(KZ_BOOKMARK(root), root->sessions);
 	kz_bookmark_append(KZ_BOOKMARK(root), root->windows);
@@ -257,7 +263,37 @@ kz_root_bookmark_set_scrap_file (KzRootBookmark *root,
 	{
 		root->scrap = scrap;
 		kz_bookmark_insert_before(KZ_BOOKMARK(root),
-					  scrap, root->bookmark_bars);
+					  scrap, root->smarts);
+	}
+}
+
+
+void
+kz_root_bookmark_add_smartbookmark_file (KzRootBookmark *root,
+			 	 	 const gchar *file,
+				 	 const gchar *subfile)
+{
+	KzBookmark *smart;
+
+	g_return_if_fail(KZ_IS_ROOT_BOOKMARK(root));
+	g_return_if_fail(file && *file);
+
+	/* FIXME! Check permission */
+
+	smart = ensure_bookmark_file(file, subfile, _("SmartBookmarks"), "XBEL");
+
+	if (root->smarts)
+	{
+		kz_bookmark_remove(KZ_BOOKMARK(root), root->smarts);
+		g_object_unref(G_OBJECT(root->smarts));
+		root->smarts = NULL;
+	}
+
+	if (smart)
+	{
+		root->smarts = smart;
+		kz_bookmark_insert_before(KZ_BOOKMARK(root),
+					  smart, root->bookmark_bars);
 	}
 }
 
@@ -329,4 +365,6 @@ kz_root_bookmark_save_all (KzRootBookmark *root)
 		}
 		g_list_free(children);
 	}
+	if (root->smarts)
+		kz_bookmark_save(root->smarts);
 }
