@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-root-bookmark.h,v 1.3 2004/03/20 07:08:30 makeinu Exp $
+ *  $Id: kz-root-bookmark.h,v 1.5 2004/07/08 08:01:24 ikezoe Exp $
  */
 
 #ifndef __KZ_ROOT_BOOKMARK_H__
@@ -44,11 +44,11 @@ struct _KzRootBookmark
 	KzBookmark parent;
 
 	KzBookmark *menu;
-	KzBookmark *home;
 	KzBookmark *scrap;
 	KzBookmark *bookmark_bars;
 	KzHistory  *history;
 
+	KzBookmark *smarts;
 	/* ??? */
 	KzBookmark *sessions;
 	KzBookmark *windows;
@@ -68,22 +68,21 @@ GType		kz_root_bookmark_get_type	      (void);
 
 KzRootBookmark *kz_root_bookmark_new		      (const gchar *menu_file,
 						       const gchar *sys_menu_file,
-						       const gchar *home_file,
-						       const gchar *sys_home_file,
 						       const gchar *scrap_file,
 						       const gchar *sys_scrap_file);
 void		kz_root_bookmark_set_menu_file	      (KzRootBookmark *root,
 						       const gchar    *file,
 						       const gchar    *subfile);
-void		kz_root_bookmark_set_home_file	      (KzRootBookmark *root,
-						       const gchar    *file,
-						       const gchar    *subfile);
 void		kz_root_bookmark_set_scrap_file	      (KzRootBookmark *root,
 						       const gchar    *file,
 						       const gchar    *subfile);
 void		kz_root_bookmark_add_bookmark_bar_file(KzRootBookmark *root,
 						       const gchar    *file,
 						       const gchar    *subfile);
+void	        kz_root_bookmark_add_smartbookmark_file
+						      (KzRootBookmark *root,
+						       const gchar    *file,
+						       const gchar    *subfile);
 void		kz_root_bookmark_set_history_file     (KzRootBookmark *root,
 						       const gchar    *file);
 
