@@ -18,12 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-bookmark-item.c,v 1.15 2004/05/05 02:25:56 ikezoe Exp $
- */
-
-/*
- *  TODO:
- *      * Show favicons instead of buttons for normal bookmark.
+ *  $Id: kz-bookmark-item.c,v 1.21 2004/07/05 09:17:08 ikezoe Exp $
  */
 
 #include "kz-bookmark-item.h"
@@ -46,6 +41,15 @@ enum {
 	PROP_KZ_WINDOW
 };
 
+enum {
+	TARGET_KAZEHAKASE_BOOKMARKS,
+};
+
+static GtkTargetEntry dnd_types[] = {
+	{"_KAZEHAKASE_BOOKMARKS", 0, TARGET_KAZEHAKASE_BOOKMARKS},
+};
+
+static const gint dnd_types_num = G_N_ELEMENTS(dnd_types);
 
 static void     kz_bookmark_item_class_init       (KzBookmarkItemClass *klass);
 static void     kz_bookmark_item_init             (KzBookmarkItem *menu);
@@ -63,11 +67,17 @@ static void     kz_bookmark_item_get_property     (GObject        *object,
 						   guint           prop_id,
 						   GValue         *value,
 						   GParamSpec     *pspec);
+/* widget class methods */
+static void     kz_bookmark_item_drag_data_get    (GtkWidget        *widget,
+						   GdkDragContext   *context,
+						   GtkSelectionData *seldata,
+						   guint             info,
+						   guint             time);
+static void     kz_bookmark_item_drag_begin       (GtkWidget        *widget,
+						   GdkDragContext   *context);
 
 /* private methods */
 static void     kz_bookmark_item_reset_submenu    (KzBookmarkItem *menu);
-static void     open_all_items                    (KzBookmark *bookmark,
-						   KzWindow *kz);
 
 /* callback for bookmark objects */
 static void     cb_bookmark_load_start            (KzBookmark *bookmark,
@@ -81,20 +91,20 @@ static void     bookmark_weak_ref                 (gpointer data,
 						   GObject *obj);
 
 /* callbacks for child widgets */
-static gboolean cb_bookmark_menu_press            (GtkWidget *widget,
-						   GdkEventButton *event,
-						   KzBookmarkItem *menu);
-static void     cb_update_button_clicked          (GtkWidget *widget,
-						   KzBookmarkItem *menu);
-static void     cb_menuitem_destroy               (GtkWidget *widget,
-						   KzBookmark *item);
+static gboolean cb_bookmark_menu_release          (GtkWidget        *widget,
+						   GdkEventButton   *event,
+						   KzBookmarkItem   *menu);
+static void     cb_update_button_clicked          (GtkWidget        *widget,
+						   KzBookmarkItem   *menu);
+static void     cb_menuitem_destroy               (GtkWidget        *widget,
+						   KzBookmark       *item);
 
 /* manage life cycle of both menuitems and bookmarks */
 static void     connect_observe_signals           (GtkWidget *widget,
 						   KzBookmark *item);
 
 
-static GtkBinClass *parent_class = NULL;
+static GtkHBoxClass *parent_class = NULL;
 
 
 KZ_OBJECT_GET_TYPE(kz_bookmark_item, "KzBookmarkItem", KzBookmarkItem,
@@ -105,10 +115,12 @@ static void
 kz_bookmark_item_class_init (KzBookmarkItemClass *klass)
 {
 	GObjectClass *gobject_class;
+	GtkWidgetClass *widget_class;
 
 	parent_class = g_type_class_peek_parent (klass);
 
 	gobject_class = (GObjectClass *) klass;
+	widget_class  = (GtkWidgetClass *) klass;
 
 	/* GObject signals */
 	gobject_class->dispose      = kz_bookmark_item_dispose;
@@ -116,6 +128,9 @@ kz_bookmark_item_class_init (KzBookmarkItemClass *klass)
 	gobject_class->set_property = kz_bookmark_item_set_property;
 	gobject_class->get_property = kz_bookmark_item_get_property;
 
+	widget_class->drag_data_get = kz_bookmark_item_drag_data_get;
+	widget_class->drag_begin    = kz_bookmark_item_drag_begin;
+
 	g_object_class_install_property
 		(gobject_class,
 		 PROP_BOOKMARK,
@@ -172,7 +187,6 @@ kz_bookmark_item_constructor (GType                  type,
 	gtk_container_set_border_width(GTK_CONTAINER(menu), 2);
 
 	/* button */
-	/* FIXME!: show favicon? */
 	menu->update_button = button = gtk_button_new();
 	gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
 	gtk_box_pack_start(hbox, button, FALSE, FALSE, 0);
@@ -185,37 +199,38 @@ kz_bookmark_item_constructor (GType                  type,
 			= gtk_image_new_from_stock(KZ_STOCK_GREEN,
 						   KZ_ICON_SIZE_BOOKMARK_MENU);
 	}
-	else if(is_folder)
-	{
-		g_signal_connect(G_OBJECT(button), "button_press_event",
-			 	 G_CALLBACK(cb_bookmark_menu_press), menu);
-		menu->image = image
-			= gtk_image_new_from_stock(KZ_STOCK_FOLDER,
-						   KZ_ICON_SIZE_BOOKMARK_MENU);
-	}
 	else
 	{
-		KzFavicon *kzfav;
-		GtkWidget *favicon = NULL;
-
-		g_signal_connect(G_OBJECT(button), "button_press_event",
-			 	 G_CALLBACK(cb_bookmark_menu_press), menu);
-		/* favicon */
-		kzfav = kz_favicon_get_instance();
-		favicon	= kz_favicon_get_widget(kzfav,
-						kz_bookmark_get_link(menu->bookmark),
-						KZ_ICON_SIZE_BOOKMARK_MENU);
-		if (favicon)
+		g_signal_connect(G_OBJECT(button), "button_release_event",
+			 	 G_CALLBACK(cb_bookmark_menu_release), menu);
+		if(is_folder)
 		{
-			menu->image = image = favicon;
+			menu->image = image
+				= gtk_image_new_from_stock(KZ_STOCK_FOLDER,
+							   KZ_ICON_SIZE_BOOKMARK_MENU);
 		}
 		else
 		{
-			menu->image = image
-				= gtk_image_new_from_stock(KZ_STOCK_BOOKMARK,
-							   KZ_ICON_SIZE_BOOKMARK_MENU);
+			KzFavicon *kzfav;
+			GtkWidget *favicon = NULL;
+
+			/* favicon */
+			kzfav = kz_favicon_get_instance();
+			favicon	= kz_favicon_get_widget(kzfav,
+							kz_bookmark_get_link(menu->bookmark),
+							KZ_ICON_SIZE_BOOKMARK_MENU);
+			if (favicon)
+			{
+				menu->image = image = favicon;
+			}
+			else
+			{
+				menu->image = image
+					= gtk_image_new_from_stock(KZ_STOCK_BOOKMARK,
+								   KZ_ICON_SIZE_BOOKMARK_MENU);
+			}
+			g_object_unref(kzfav);
 		}
-		g_object_unref(kzfav);
 	}
 	gtk_container_add(GTK_CONTAINER(button), image);
 	gtk_widget_show(image);
@@ -246,14 +261,22 @@ kz_bookmark_item_constructor (GType                  type,
 	eventbox = kz_input_event_box_new();
 	menu->eventbox = eventbox;
 	gtk_box_pack_start(hbox, eventbox, FALSE, FALSE, 0);
-	g_signal_connect(G_OBJECT(eventbox), "button_press_event",
-			 G_CALLBACK(cb_bookmark_menu_press), menu);
+	g_signal_connect(G_OBJECT(eventbox), "button_release_event",
+			 G_CALLBACK(cb_bookmark_menu_release), menu);
 	gtk_widget_show (eventbox);
 
 	menu->label = gtk_label_new(kz_bookmark_get_title(menu->bookmark));
 	gtk_container_add(GTK_CONTAINER(eventbox), menu->label);
 	gtk_widget_show (menu->label);
 
+	gtk_drag_source_set(GTK_WIDGET(menu),
+			    GDK_BUTTON1_MASK |
+			    GDK_BUTTON2_MASK |
+			    GDK_BUTTON3_MASK,
+			    dnd_types,
+			    dnd_types_num,
+			    GDK_ACTION_ASK  | GDK_ACTION_COPY
+			    | GDK_ACTION_MOVE | GDK_ACTION_LINK);
 	/* submenu */
 	kz_bookmark_item_reset_submenu(menu);
 
@@ -390,52 +413,6 @@ kz_bookmark_item_reset_submenu (KzBookmarkItem *menu)
 }
 
 
-static void
-open_all_items (KzBookmark *bookmark, KzWindow *kz)
-{
-	GList *node, *items;
-	KzBookmark *item = NULL;
-	GtkWidget *parent = NULL;
-	const gchar *channel_uri;
-	gboolean confirm;
-
-	/* confirmation */
-	KZ_CONF_GET("Global", "confirm_open_bookmarks", confirm, BOOL);
-	if (confirm)
-	{
-		GtkWidget *dialog;
-		gint res;
-		dialog = gtk_message_dialog_new(GTK_WINDOW(kz),
-						GTK_DIALOG_DESTROY_WITH_PARENT,
-						GTK_MESSAGE_QUESTION,
-						GTK_BUTTONS_YES_NO,
-						_("Open all bookmarks in this bookmark folder ?"));
-		gtk_dialog_set_default_response(GTK_DIALOG(dialog),
-						GTK_RESPONSE_YES);
-		res = gtk_dialog_run(GTK_DIALOG(dialog));
-		gtk_widget_destroy(dialog);
-	
-		if (res == GTK_RESPONSE_NO) return;
-	}
-
-	channel_uri = kz_bookmark_get_link(bookmark);
-	if (channel_uri)
-		parent = kz_window_open_new_tab(kz, channel_uri);
-
-	items = kz_bookmark_get_children(bookmark);
-	for (node = items; node; node = g_list_next(node))
-	{
-		const gchar *uri;
-
-		item = node->data;
-		uri = kz_bookmark_get_link(item);
-		if (uri)
-			kz_window_open_new_tab_with_parent(kz, uri, parent);
-	}
-	g_list_free(items);
-}
-
-
 /*****************************************************************************
  *                                                                           *
  *                                Callbacks                                  *
@@ -505,8 +482,8 @@ bookmark_weak_ref (gpointer data, GObject *obj)
 
 
 static gboolean
-cb_bookmark_menu_press (GtkWidget *widget, GdkEventButton *event,
-			KzBookmarkItem *menu)
+cb_bookmark_menu_release (GtkWidget *widget, GdkEventButton *event,
+			  KzBookmarkItem *menu)
 {
 	KzWindow *kz;
 	GdkEventButton *event_button;
@@ -526,7 +503,7 @@ cb_bookmark_menu_press (GtkWidget *widget, GdkEventButton *event,
 			gtk_menu_popup(GTK_MENU(menu->sub_menu), NULL, NULL, 
 				       gtkutil_menu_position_under_widget,
 				       GTK_WIDGET(menu),
-				       event_button->button, event_button->time);
+				       0, event_button->time);
 		}
 		else
 		{
@@ -538,7 +515,13 @@ cb_bookmark_menu_press (GtkWidget *widget, GdkEventButton *event,
 	case 2:
 		if (kz_bookmark_is_folder(menu->bookmark))
 		{
-			open_all_items (menu->bookmark, kz);
+			GtkAction *action;
+			kz_actions_set_bookmark_for_action(kz, menu->bookmark);
+			action = gtk_action_group_get_action(kz->actions,
+							     "OpenAllBookmarks");
+			if (action)
+				gtk_action_activate(action);
+			kz_actions_set_bookmark_for_action(kz, NULL);
 		}
 		else
 		{
@@ -552,6 +535,8 @@ cb_bookmark_menu_press (GtkWidget *widget, GdkEventButton *event,
 						     event->button,
 						     event->time);
 		break;
+	default:
+		break;
 	}
 
 	return TRUE;
@@ -577,6 +562,46 @@ cb_menuitem_destroy(GtkWidget *widget, KzBookmark *item)
 }
 
 
+static void
+kz_bookmark_item_drag_data_get (GtkWidget *widget,
+				GdkDragContext *context,
+				GtkSelectionData *seldata,
+				guint info,
+				guint time)
+{
+	switch (info)
+	{
+	case TARGET_KAZEHAKASE_BOOKMARKS:
+		gtk_selection_data_set(seldata, seldata->target,
+				       8, "dummy", strlen("dummy"));
+		break;
+	}
+}
+
+
+static void
+kz_bookmark_item_drag_begin (GtkWidget *widget, GdkDragContext *context)
+{
+	KzBookmarkItem *item;
+	KzBookmark *bookmark;
+	const gchar *stock_id;
+
+	g_return_if_fail(KZ_IS_BOOKMARK_ITEM(widget));
+
+	item = KZ_BOOKMARK_ITEM(widget);
+	bookmark = item->bookmark;
+
+	if (kz_bookmark_is_file(bookmark))
+		stock_id = KZ_STOCK_REMOTE_BOOKMARK;
+	else if (kz_bookmark_is_folder(bookmark))
+		stock_id = KZ_STOCK_FOLDER;
+	else
+		stock_id = KZ_STOCK_BOOKMARK;
+
+	gtk_drag_source_set_icon_stock(widget, stock_id);
+}
+
+
 static void
 connect_observe_signals (GtkWidget *widget, KzBookmark *item)
 {
