@@ -28,6 +28,8 @@ struct _KzFaviconPriv
 {
 	GHashTable *uri_hash;
 	KzProfile  *uri_list;
+
+	guint n_favicon;
 };
 
 enum {
@@ -35,7 +37,7 @@ enum {
 	LAST_SIGNAL
 };
 
-#define MAX_FAVICONS 1000
+#define MAX_FAVICONS 2000
 #define g_strcmp(s1,s2) ((s1)!=NULL && (s2)!=NULL?strcmp(s1,s2):0)
 
 static void kz_favicon_class_init   (KzFaviconClass *klass);
@@ -110,6 +112,7 @@ kz_favicon_init (KzFavicon *kzfav)
 						       (GDestroyNotify)g_free,
 						       (GDestroyNotify)g_free);
 	kz_favicon_load_uri_list(kzfav);
+	kz_profile_close(kzfav->priv->uri_list);
 }
 
 
@@ -117,11 +120,21 @@ static void
 kz_favicon_dispose (GObject *object)
 {
 	KzFavicon *kzfav;
+	gchar *favicon_file;
 
 	g_return_if_fail(KZ_IS_FAVICON(object));
 
 	kzfav = KZ_FAVICON(object);
+	favicon_file = g_strconcat(g_get_home_dir(),
+				   "/.kazehakase/faviconrc",
+				   NULL);
+	
+	kzfav->priv->uri_list = kz_profile_open(favicon_file, NULL);
+	g_free(favicon_file);
 
+	kz_profile_delete_section(kzfav->priv->uri_list, "URI");
+	kzfav->priv->n_favicon = 0;
+	
 	/* convert hash table to KzProfileList */
 	g_hash_table_foreach(kzfav->priv->uri_hash,
 			     (GHFunc)kz_favicon_uri_hash_to_uri_list,
@@ -184,10 +197,15 @@ kz_favicon_load_uri_list (KzFavicon *kzfav)
 static void
 kz_favicon_uri_hash_to_uri_list (gpointer key, gpointer value, KzFavicon *kzfav)
 {
+	if (kzfav->priv->n_favicon > MAX_FAVICONS)
+		return;
+
 	kz_profile_set_value(kzfav->priv->uri_list, "URI",
 			     (const gchar*)key, (const gchar *)value,
 			     strlen((gchar *)value) + 1,
 			     KZ_PROFILE_VALUE_TYPE_STRING);
+
+	kzfav->priv->n_favicon++;
 }
 
 
@@ -216,6 +234,8 @@ cb_favicon_uri_notify (KzMozEmbed *kzembed,
 					    "/.kazehakase/favicon/",
 					    favicon_filename,
 					    NULL);
+	g_free(favicon_filename);
+	
 	old_value = g_hash_table_lookup(kzfav->priv->uri_hash,
 					hash_key);
 	
@@ -223,12 +243,14 @@ cb_favicon_uri_notify (KzMozEmbed *kzembed,
 	{
 		GQuark quark;
 		quark = g_quark_from_string(location);
-		/* FIXME! Do not use kzfavicon_sigle object! */
-		g_signal_emit(G_OBJECT(kzfavicon_single),
+		
+		g_signal_emit(kzfav,
 			      kz_favicon_signals[READY_SIGNAL],
 			      quark,
 			      location);
-		goto END;
+		g_free(hash_key);
+		g_free(favicon_file_location);
+		return;
 	}
 
 	g_hash_table_insert(kzfav->priv->uri_hash,
@@ -237,19 +259,18 @@ cb_favicon_uri_notify (KzMozEmbed *kzembed,
 
 	/* start download */
 	dl = kz_downloader_new_with_filename(favicon_uri, favicon_file_location);
-	if (!dl) goto END;
+	if (dl)
+	{
+		g_signal_connect(G_OBJECT(dl), "completed",
+				 G_CALLBACK(cb_downloader_load_complete),
+				 (gpointer)location);
+		g_signal_connect(G_OBJECT(dl), "error",
+				 G_CALLBACK(cb_downloader_load_error),
+				 (gpointer)location);
+		kz_downloader_to_file(dl);
+	}
 
-	g_signal_connect(G_OBJECT(dl), "completed",
-			 G_CALLBACK(cb_downloader_load_complete),
-			 (gpointer)location);
-	g_signal_connect(G_OBJECT(dl), "error",
-			 G_CALLBACK(cb_downloader_load_error),
-			 (gpointer)location);
-	kz_downloader_to_file(dl);
-
-END:
 	g_free(hash_key);
-	g_free(favicon_filename);
 	g_free(favicon_file_location);
 }
 
