@@ -28,6 +28,7 @@
 
 enum {
    START_SIGNAL,
+   CANCEL_SIGNAL,
    STACK_MOTION_SIGNAL,
    PERFORM_SIGNAL,
    LAST_SIGNAL
@@ -40,6 +41,7 @@ static void kz_gesture_dispose      (GObject *object);
 /* KzGesture class signals */
 static void kz_gesture_stack_motion (KzGesture *gesture,
 				     KzGestureMotion motion);
+static void kz_gesture_real_perform (KzGesture *gesture);
 
 static void kz_gesture_reset        (KzGesture *gesture);
 static KzGestureItem *kz_gesture_search_matched_item (KzGesture *gesture);
@@ -60,6 +62,31 @@ kz_gesture_class_init (KzGestureClass *klass)
 	parent_class = g_type_class_peek_parent (klass);
 	object_class = (GObjectClass *) klass;
 
+	object_class->dispose = kz_gesture_dispose;
+
+	klass->start        = NULL;
+	klass->cancel       = NULL;
+	klass->stack_motion = kz_gesture_stack_motion;
+	klass->perform      = kz_gesture_real_perform;
+
+	kz_gesture_signals[START_SIGNAL]
+		= g_signal_new ("start",
+				G_TYPE_FROM_CLASS (klass),
+				G_SIGNAL_RUN_FIRST,
+				G_STRUCT_OFFSET (KzGestureClass, start),
+				NULL, NULL,
+				g_cclosure_marshal_VOID__VOID,
+				G_TYPE_NONE, 0);
+
+	kz_gesture_signals[CANCEL_SIGNAL]
+		= g_signal_new ("cancel",
+				G_TYPE_FROM_CLASS (klass),
+				G_SIGNAL_RUN_FIRST,
+				G_STRUCT_OFFSET (KzGestureClass, cancel),
+				NULL, NULL,
+				g_cclosure_marshal_VOID__VOID,
+				G_TYPE_NONE, 0);
+
 	kz_gesture_signals[STACK_MOTION_SIGNAL]
 		= g_signal_new ("stack-motion",
 				G_TYPE_FROM_CLASS (klass),
@@ -69,11 +96,14 @@ kz_gesture_class_init (KzGestureClass *klass)
 				g_cclosure_marshal_VOID__ENUM,
 				G_TYPE_NONE, 1, G_TYPE_INT);
 
-	object_class->dispose = kz_gesture_dispose;
-
-	klass->start        = NULL;
-	klass->stack_motion = kz_gesture_stack_motion;
-	klass->perform      = NULL;
+	kz_gesture_signals[PERFORM_SIGNAL]
+		= g_signal_new ("perform",
+				G_TYPE_FROM_CLASS (klass),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (KzGestureClass, perform),
+				NULL, NULL,
+				g_cclosure_marshal_VOID__VOID,
+				G_TYPE_NONE, 0);
 }
 
 static void
@@ -125,6 +155,18 @@ kz_gesture_set_items (KzGesture *gesture, KzGestureItems *items)
 		gesture->items = NULL;
 }
 
+static void
+kz_gesture_real_perform (KzGesture *gesture)
+{
+	KzGestureItem *item;
+
+	item = kz_gesture_search_matched_item(gesture);
+	if (item)
+		gtk_action_activate(item->action);
+
+	kz_gesture_reset(gesture);
+}
+
 static void
 kz_gesture_stack_motion (KzGesture *gesture, KzGestureMotion motion)
 {
@@ -148,35 +190,32 @@ kz_gesture_stack_motion (KzGesture *gesture, KzGestureMotion motion)
 	seq[len] = '\0';
 }
 
-gboolean
+void
 kz_gesture_start (KzGesture *gesture, gint mode, gint x, gint y)
 {
+	g_return_if_fail(KZ_IS_GESTURE(gesture));
+
 	gesture->current_mode = mode;
 	gesture->prev_x = gesture->x = x;
 	gesture->prev_y = gesture->y = y;
 	gesture->started = TRUE;
 
-	return TRUE;
+	g_signal_emit(G_OBJECT(gesture), kz_gesture_signals[START_SIGNAL], 0);
 }
 
-gboolean
+void
 kz_gesture_perform (KzGesture *gesture)
 {
-	KzGestureItem *item;
+	g_return_if_fail(KZ_IS_GESTURE(gesture));
 
-	item = kz_gesture_search_matched_item(gesture);
-	if (item)
-		egg_action_activate(item->action);
-
-	kz_gesture_reset(gesture);
-
-	return FALSE;
+	g_signal_emit(G_OBJECT(gesture), kz_gesture_signals[PERFORM_SIGNAL], 0);
 }
 
 void
 kz_gesture_cancel (KzGesture *gesture)
 {
 	kz_gesture_reset (gesture);
+	g_signal_emit(G_OBJECT(gesture), kz_gesture_signals[CANCEL_SIGNAL], 0);
 }
 
 static void
@@ -338,7 +377,7 @@ kz_gesture_get_matched_label (KzGesture *gesture)
 	item = kz_gesture_search_matched_item (gesture);
 	if (!item) return NULL;
 	g_return_val_if_fail(item->action, NULL);
-	return item->action->name;
+	return gtk_action_get_name(item->action);
 }
 
 void
@@ -464,7 +503,7 @@ static gint
 compare_gesture_item (gconstpointer data1, gconstpointer data2)
 {
 	const KzGestureItem *item = data1;
-	const EggAction *action = EGG_ACTION(data2);
+	const GtkAction *action = GTK_ACTION(data2);
 
 	return item->action - action;
 }
@@ -485,14 +524,14 @@ kz_gesture_item_destroy (KzGestureItem *item)
 
 void
 kz_gesture_items_set_action (KzGestureItems *items,
-			     EggAction *action, gint mode,
+			     GtkAction *action, gint mode,
 			     const KzGestureMotion *sequence)
 {
 	KzGestureItem *item;
 	GSList *node;
 
 	g_return_if_fail(items);
-	g_return_if_fail(EGG_IS_ACTION(action));
+	g_return_if_fail(GTK_IS_ACTION(action));
 	g_return_if_fail(sequence && *sequence != '\0');
 
 	if(!validate_gesture_sequence(sequence))
@@ -524,18 +563,19 @@ kz_gesture_items_set_action (KzGestureItems *items,
 
 void
 kz_gesture_items_unset_action (KzGestureItems *items,
-			       EggAction *action)
+			       GtkAction *action)
 {
 	KzGestureItem *item;
 	GSList *node;
 
 	g_return_if_fail(items);
-	g_return_if_fail(EGG_IS_ACTION(action));
+	g_return_if_fail(GTK_IS_ACTION(action));
 
 	node = g_slist_find_custom(items->list, action,
 				   compare_gesture_item);
 	if (!node) return;
 
 	item = node->data;
+	items->list = g_slist_remove(items->list, item);
 	kz_gesture_item_destroy(item);
 }
