@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-icons.h,v 1.11 2004/05/12 14:43:55 ikezoe Exp $
+ *  $Id: kz-icons.h,v 1.20 2004/07/28 11:02:12 ikezoe Exp $
  */
 
 #ifndef KZ_ICONS_H
@@ -38,7 +38,22 @@ G_BEGIN_DECLS
 #define KZ_STOCK_BOOKMARK        "kz-bookmark"
 #define KZ_STOCK_REMOTE_BOOKMARK "kz-remote-bookmark"
 #define KZ_STOCK_SCRAP_BOOKMARK  "kz-scrap-bookmark"
+#define KZ_STOCK_SMART_BOOKMARK  "kz-smart-bookmark"
 #define KZ_STOCK_EDITOR          "kz-editor"
+#define KZ_STOCK_HISTORY         "kz-history"
+#define KZ_STOCK_TAB_NEXT        "kz-tab-next"
+#define KZ_STOCK_TAB_PREV        "kz-tab-prev"
+#define KZ_STOCK_SEARCH          "kz-search"
+#define KZ_STOCK_SAVE_LINK       "kz-savelink"
+#define KZ_STOCK_CLOSE_WINDOW    "kz-closewindow"
+#define KZ_STOCK_CLOSE_FORWARD   "kz-closeforward"
+#define KZ_STOCK_CLOSE_BACKWARD  "kz-closebackward"
+#define KZ_STOCK_NEW_WINDOW      "kz-newwindow"
+#define KZ_STOCK_OPEN_LINK_WINDOW "kz-openlinkwindow"
+#define KZ_STOCK_OPEN_IMAGE_WINDOW "kz-openimagewindow"
+#define KZ_STOCK_OPEN_SELECTED_LINK "kz-openselectedlink"
+#define KZ_STOCK_COPY_URL        "kz-copyurl"
+#define KZ_STOCK_COPY_IMAGE_URL  "kz-copyimagelocation"
 
 extern GtkIconSize KZ_ICON_SIZE_BOOKMARK_MENU;
 
