@@ -233,7 +233,8 @@ GList *kz_profile_enum_section (KzProfile *profile);
  * @RET,list of keys,NULL:error
 */
 GList *kz_profile_enum_key (KzProfile *profile,
-			    const gchar *section);
+			    const gchar *section,
+			    gboolean users_only);
 
 G_END_DECLS
 
