@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: kz-xml.c,v 1.19 2004/04/13 01:27:48 ikezoe Exp $
+ *  $Id: kz-xml.c,v 1.21 2004/07/28 04:58:46 ikezoe Exp $
  */
 
 #include "kz-xml.h"
@@ -279,6 +279,7 @@ kz_xml_load_xml (KzXML *xml, const gchar *buffer, guint length)
 	else
 	{
 		g_warning("Bookmark parse error!: %s", error->message);
+		g_error_free(error);
 	}
 	g_markup_parse_context_free (context);
 	xml->priv->context = NULL;
@@ -493,12 +494,13 @@ kz_xml_node_append_xml_string (KzXMLNode *node, GString *gstr)
 	else if (node->type == KZ_XML_NODE_TEXT)
 	{
 		gchar *escaped;
-//		escaped = g_strdup(node->content);
 
 		escaped = g_markup_escape_text(node->content, -1);
 		if (escaped)
+		{
 			g_string_append(gstr, escaped);
-		g_free(escaped);
+			g_free(escaped);
+		}
 	}
 	else
 	{
