@@ -26,7 +26,7 @@
 #include <gtkmozembed.h>
 #include "kazehakase.h"
 #include "kz-embed-event.h"
-#include "egg-menu-merge.h"
+#include "gtk24backports.h"
 
 G_BEGIN_DECLS
 
@@ -116,7 +116,7 @@ gboolean     kz_moz_embed_get_links          (KzMozEmbed   *kzembed,
 					      gboolean      selected_only);
 
 void         kz_moz_embed_add_ui             (KzMozEmbed   *kzembed,
-					      EggMenuMerge *ui,
+					      GtkUIManager *ui,
 					      KzUILevel     level);
 void         kz_moz_embed_remove_ui          (KzMozEmbed   *kzembed);
 
@@ -190,6 +190,8 @@ gboolean     kz_moz_embed_set_text_into_textarea (KzMozEmbed *kzembed,
 gchar       *kz_moz_embed_get_text_from_textarea (KzMozEmbed *kzembed,
 						  gpointer element);
 
+gchar	    *kz_moz_embed_store_history_file (KzMozEmbed *kzembed);
+
 G_END_DECLS
 
 #endif /* __KZ_MOZ_EMBED_H__ */
