@@ -29,20 +29,20 @@
 #include <kz-mozwrapper.h>
 #include <gtkmozembed_internal.h>
 
-#include <xpcom/nsIInterfaceRequestorUtils.h>
-#include <xpcom/nsILocalFile.h>
+#include <nsIInterfaceRequestorUtils.h>
+#include <nsILocalFile.h>
 #include <docshell/nsIDocShell.h>
 #include <docshell/nsIDocShellTreeItem.h>
 #include <docshell/nsIDocShellTreeOwner.h>
 #include <docshell/nsIContentViewer.h>
 #include <content/nsIContent.h>
-#include <dom/nsIDOMHTMLDocument.h>
-#include <dom/nsIDOMHTMLElement.h>
-#include <dom/nsIDOMHTMLImageElement.h>
-#include <dom/nsIDOMDocumentRange.h>
-#include <dom/nsIDOMNamedNodeMap.h>
-#include <dom/nsIDOMText.h>
-#include <dom/nsIDOMNodeList.h>
+#include <nsIDOMHTMLDocument.h>
+#include <nsIDOMHTMLElement.h>
+#include <nsIDOMHTMLImageElement.h>
+#include <nsIDOMDocumentRange.h>
+#include <nsIDOMNamedNodeMap.h>
+#include <nsIDOMText.h>
+#include <nsIDOMNodeList.h>
 #include <nsIClipboardCommands.h>
 #include <nsLiteralString.h>
 #include <nsString.h>
@@ -140,8 +140,11 @@ KzMozWrapper::GetListener (void)
   	if (!piWin) return NS_ERROR_FAILURE;
 
   	nsCOMPtr<nsIChromeEventHandler> chromeHandler;
-  	piWin->GetChromeEventHandler(getter_AddRefs(chromeHandler));
-
+#if MOZILLA_SNAPSHOT > 15
+	chromeHandler = piWin->GetChromeEventHandler();
+#else
+	piWin->GetChromeEventHandler(getter_AddRefs(chromeHandler));	
+#endif
   	mEventReceiver = do_QueryInterface(chromeHandler);
 	if (!mEventReceiver) return NS_ERROR_FAILURE;
 
@@ -1000,7 +1003,8 @@ KzMozWrapper::MoveImageToLocal (const nsACString &URI, nsAString &LocalFile)
 		nsCOMPtr<nsIInputStream> inStream;
 
 		gchar *dir, *buf;
-		gchar *filename = create_filename_from_uri(ToNewCString(URI));
+		gchar *uri = ToNewCString(URI);
+		gchar *filename = create_filename_from_uri(uri);
 
 		dir = g_strconcat(g_get_home_dir(),
 				  "/.kazehakase/",
@@ -1035,6 +1039,7 @@ KzMozWrapper::MoveImageToLocal (const nsACString &URI, nsAString &LocalFile)
 		g_free(filename);
 		g_free(dir);
 		g_free(buf);
+		g_free(uri);
 	}
 }
 
@@ -1076,3 +1081,68 @@ KzMozWrapper::PrintPreview (void)
 
 	return result;
 }
+
+#if 0
+nsresult
+KzMozWrapper::StoreHistoryFile (const nsACString &URI)
+{
+	nsresult rv;
+	nsCOMPtr<nsICacheEntryDescriptor> cacheEntryDescriptor;
+	rv = GetCacheEntryDescriptor(NS_ConvertUTF8toUCS2(URI),
+				     getter_AddRefs(cacheEntryDescriptor));
+
+	if (NS_SUCCEEDED(rv) && cacheEntryDescriptor)
+	{
+		PRUint32 dataSize = 0;
+		nsCOMPtr<nsIInputStream> inStream;
+
+		gchar *dir, *buf;
+		gchar *uri = ToNewCString(URI);
+		gchar *filename;
+		filename = create_filename_with_path_from_uri(uri);
+		
+		if (!filename)
+			filename = g_strdup("index.html");
+
+		dir = g_strconcat(g_get_home_dir(),
+				  "/.kazehakase/history/",
+				  filename,
+				  NULL);
+		g_free(filename);
+		g_free(uri);
+
+		cacheEntryDescriptor->GetDataSize(&dataSize);
+		cacheEntryDescriptor->OpenInputStream(0, getter_AddRefs(inStream));
+
+		buf = g_new0(gchar, dataSize);
+
+		inStream->Read(buf, dataSize, &rv);
+		inStream->Close();
+		
+		make_dir("history");
+		
+		nsCOMPtr<nsILocalFile> localFile = do_CreateInstance(NS_LOCAL_FILE_CONTRACTID);
+
+		rv = localFile->InitWithPath(NS_ConvertUTF8toUCS2(dir));
+		g_free(dir);
+
+		if (NS_SUCCEEDED(rv))
+		{
+			rv = localFile->Create(nsIFile::NORMAL_FILE_TYPE, 0600);
+			if (NS_SUCCEEDED(rv))
+			{
+				nsCOMPtr<nsIOutputStream> outStream;
+				NS_NewLocalFileOutputStream(getter_AddRefs(outStream),
+							    localFile,
+							    -1,
+							    0600);
+				outStream->Write(buf, dataSize, &rv);
+				outStream->Close();
+			}
+		}
+		g_free(buf);
+	}
+
+	return rv;
+}
+#endif
