@@ -24,13 +24,13 @@
 #include <sys/utsname.h>
 #include <gtkmozembed.h>
 #include <nsBuildID.h>
-#include <xpcom/nsCOMPtr.h>
-#include <pref/nsIPrefService.h>
+#include <nsCOMPtr.h>
+#include <nsIPrefService.h>
 #include <uconv/nsICharsetConverterManager.h>
 #if MOZILLA_SNAPSHOT < 10
 #	include <uconv/nsICharsetConverterManager2.h>
 #endif
-#include <xpcom/nsISupportsPrimitives.h>
+#include <nsISupportsPrimitives.h>
 #include <gfx/nsIFontList.h>
 #include <necko/nsNetUtil.h>
 
@@ -89,7 +89,7 @@ mozilla_prefs_set (void)
 {
 	char *value;
 	gchar user_agent[1024];
-	gboolean override = FALSE, typeahead = FALSE;
+	gboolean override = FALSE;
 	gchar proxy_name[1024];
 	gboolean conf_exist = FALSE;
 	KzProxyItem *item = NULL;
@@ -103,10 +103,6 @@ mozilla_prefs_set (void)
 		build_user_agent(user_agent, G_N_ELEMENTS(user_agent));
 	mozilla_prefs_set_string ("general.useragent.override", user_agent);
 
-	// set typeahead or not
-	KZ_CONF_GET("Mozilla", "typeahead", typeahead, BOOL);
-	mozilla_prefs_set_boolean ("accessibility.typeaheadfind",
-				   typeahead);	
 	if (!mozilla_prefs_get_string("kazehakase.font.language", &value))
 	{
 		mozilla_prefs_set_string("kazehakase.font.language",
@@ -367,7 +363,12 @@ mozilla_prefs_set_proxy (KzProxyItem *item)
 	if (!use_proxy)
 	{
 		mozilla_prefs_set_int("network.proxy.type", 0);
-		return;
+		if (https_host)
+			g_free(https_host);
+		if (ftp_host)
+			g_free(ftp_host);
+
+		goto END;
 	}
 
 	mozilla_prefs_set_int   ("network.proxy.type",          1);
@@ -377,6 +378,11 @@ mozilla_prefs_set_proxy (KzProxyItem *item)
 
 	if (use_same_proxy)
 	{
+		if (https_host)
+			g_free(https_host);
+		if (ftp_host)
+			g_free(ftp_host);
+
 		https_host = ftp_host = http_host;
 		http_port = ftp_port = http_port;
 	}
@@ -397,4 +403,11 @@ mozilla_prefs_set_proxy (KzProxyItem *item)
 	mozilla_prefs_set_int   ("network.proxy.ssl_port", https_port);
 	mozilla_prefs_set_string("network.proxy.ftp",        ftp_host);
 	mozilla_prefs_set_int   ("network.proxy.ftp_port",   ftp_port);
+END:
+	if (http_host)
+		g_free(http_host);
+	if (name)
+		g_free(name);
+	if (no_proxies_on)
+		g_free(no_proxies_on);
 }
