@@ -27,6 +27,9 @@
 #include <nsCOMPtr.h>
 #include <nsIGenericFactory.h>
 #include <nsIComponentRegistrar.h>
+#include <nsIPasswordManager.h>
+#include <nsIPassword.h>
+#include <nsCPasswordManager.h>
 
 #include "mozilla.h"
 #include "mozilla-prefs.h"
@@ -36,12 +39,14 @@
 #include "kz-profile.h"
 #include "kz-proxy-item.h"
 #include "kazehakase.h"
+#include "kz-password-manager-dialog.h"
+#include "kz-mozhistorysearch.h"
 
 
 NS_GENERIC_FACTORY_CONSTRUCTOR(KzFilePicker)
 NS_GENERIC_FACTORY_CONSTRUCTOR(KzContentHandler)
 NS_GENERIC_FACTORY_CONSTRUCTOR(KzMozProgressListener)
-
+NS_GENERIC_FACTORY_CONSTRUCTOR(KzMozHistorySearchProtocolHandler)
 
 static const nsModuleComponentInfo sAppComps[] = {
 	{
@@ -62,6 +67,12 @@ static const nsModuleComponentInfo sAppComps[] = {
 		NS_IHELPERAPPLAUNCHERDLG_CONTRACTID,
 		KzContentHandlerConstructor
 	},
+	{
+		KZ_HISTORY_SEARCH_PROTOCOLHANDLER_CLASSNAME,
+		KZ_HISTORY_SEARCH_PROTOCOLHANDLER_CID,
+		KZ_HISTORY_SEARCH_PROTOCOLHANDLER_CONTRACTID,
+		KzMozHistorySearchProtocolHandlerConstructor
+	},
 };
 static const int sNumAppComps = G_N_ELEMENTS(sAppComps);
 
@@ -188,3 +199,63 @@ mozilla_exit (void)
 {
 	gtk_moz_embed_pop_startup();
 }
+
+
+extern "C" gboolean
+mozilla_get_passwords (GList **passwords)
+{
+        nsresult result = NS_ERROR_FAILURE;
+
+        nsCOMPtr<nsIPasswordManager> passwordManager =
+                        do_GetService(NS_PASSWORDMANAGER_CONTRACTID);
+        nsCOMPtr<nsISimpleEnumerator> passwordEnumerator;
+        result = passwordManager->GetEnumerator(getter_AddRefs(passwordEnumerator));
+        if (NS_FAILED(result)) return FALSE; 
+
+        PRBool enumResult;
+        for (passwordEnumerator->HasMoreElements(&enumResult) ;
+             enumResult == PR_TRUE ;
+             passwordEnumerator->HasMoreElements(&enumResult))
+        {
+                nsCOMPtr<nsIPassword> nsPassword;
+                result = passwordEnumerator->GetNext 
+                                        (getter_AddRefs(nsPassword));
+                if (NS_FAILED(result)) return FALSE;
+
+                PasswordInfo *p = g_new0 (PasswordInfo, 1);
+
+                nsCAutoString transfer;
+                nsPassword->GetHost (transfer);
+                p->host = g_strdup (transfer.get());
+
+		nsAutoString unicodeName;
+		nsPassword->GetUser (unicodeName);
+		p->username = g_strdup(NS_ConvertUCS2toUTF8(unicodeName).get());
+
+		*passwords = g_list_prepend (*passwords, p);
+        }       
+
+	*passwords = g_list_reverse (*passwords);
+
+	return TRUE;
+}
+
+
+gboolean
+mozilla_remove_passwords (GList *passwords)
+{
+	nsresult result = NS_ERROR_FAILURE;
+        nsCOMPtr<nsIPasswordManager> passwordManager =
+                        do_GetService(NS_PASSWORDMANAGER_CONTRACTID);
+
+        for (GList *l = passwords; l != NULL; l = l->next)
+        {
+                PasswordInfo *p = (PasswordInfo *)l->data;
+		result = passwordManager->RemoveUser (nsDependentCString(p->host),
+						      NS_ConvertUTF8toUCS2(nsDependentCString(p->username)));
+                if (NS_FAILED(result)) return FALSE;
+        }
+	
+        return TRUE;
+}
+
