@@ -71,6 +71,12 @@ static void
 prefs_gesture_destroy (gpointer data)
 {
 	KzPrefsGesture *self = data;
+	
+	if (self->treestore)
+	{
+		g_object_unref(self->treestore);
+		self->treestore = NULL;
+	}
 
 	g_free(self);
 }
@@ -208,7 +214,7 @@ reset_gesture_items (KzPrefsGesture *self)
 	GtkWidget *top;
 	KzWindow *kz;
 	GList *list, *node;
-	EggActionGroup *actions;
+	GtkActionGroup *actions;
 
 	g_return_if_fail(self);
 
@@ -223,12 +229,12 @@ reset_gesture_items (KzPrefsGesture *self)
 
 	/* set new list */
 	actions = kz->actions;
-	list = egg_action_group_list_actions(actions);
+	list = gtk_action_group_list_actions(actions);
 
 	for (node = list; node; node = g_list_next(node))
 	{
-		EggAction *action = node->data;
-		const gchar *name = egg_action_get_name(action);
+		GtkAction *action = node->data;
+		const gchar *name = gtk_action_get_name(action);
 		gchar *gesture;
 		GtkTreeIter iter;
 
