@@ -22,20 +22,32 @@
 #define __UTILS_H__
 
 #include <gtk/gtk.h>
+#include <time.h>
 
 G_BEGIN_DECLS
 
-void     make_dir                    (const gchar* dirname);
+void     make_dir                    (const gchar *dirname);
 gboolean key_seems_sequential        (const gchar *key,
 				      const gchar *prefix);
 gchar   *remove_tag                  (const gchar *string, gsize len);
 
 gchar   *create_filename_from_uri    (const gchar *uri);
+
+gchar   *create_filename_with_path_from_uri (const gchar *uri);
+
+gchar   *create_uri_from_filename    (const gchar *filename);
+
 gchar   *create_profile_key_from_uri (const gchar *string);
 
-gchar   *url_encode                  (const gchar* utf8src);
+gchar   *url_encode                  (const gchar *utf8src);
+gchar   *url_decode                  (const gchar *src);
 
-gchar   *complement_scheme           (const gchar* url);
+gchar   *complement_scheme           (const gchar *url);
+
+gchar   *xml_get_content	     (const gchar *buffer);
+gchar   *xml_get_attr		     (const gchar *buffer, const gchar *attr_name);
+
+void     purge_history_file	     (const gchar *path, time_t limit_seconds);
 
 G_END_DECLS
 
